"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .paymentmethodsummary_output import (
    PaymentMethodSummaryOutput,
    PaymentMethodSummaryOutputTypedDict,
)
from gr4vy.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PaymentMethodSummariesTypedDict(TypedDict):
    items: List[PaymentMethodSummaryOutputTypedDict]
    r"""A list of items returned for this request."""


class PaymentMethodSummaries(BaseModel):
    items: List[PaymentMethodSummaryOutput]
    r"""A list of items returned for this request."""



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
import pydantic
from pydantic import model_serializer
from typing_extensions import Annotated, NotRequired, TypedDict


class NuveiPSEOptionsTypedDict(TypedDict):
    user_type: NotRequired[Nullable[str]]
    r"""Customer type (\"N\" for persona natural, \"J\" for persona jurídica)"""
    user_fis_number: NotRequired[Nullable[str]]
    r"""Customer’s document type"""
    fiscal_number: NotRequired[Nullable[str]]
    r"""Customer’s document number"""
    bank_code: NotRequired[Nullable[str]]
    r"""The bank code of the selected bank"""


class NuveiPSEOptions(BaseModel):
    user_type: Annotated[OptionalNullable[str], pydantic.Field(alias="userType")] = (
        UNSET
    )
    r"""Customer type (\"N\" for persona natural, \"J\" for persona jurídica)"""

    user_fis_number: Annotated[
        OptionalNullable[str], pydantic.Field(alias="userFisNumber")
    ] = UNSET
    r"""Customer’s document type"""

    fiscal_number: Annotated[
        OptionalNullable[str], pydantic.Field(alias="fiscalNumber")
    ] = UNSET
    r"""Customer’s document number"""

    bank_code: Annotated[OptionalNullable[str], pydantic.Field(alias="bankCode")] = (
        UNSET
    )
    r"""The bank code of the selected bank"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["userType", "userFisNumber", "fiscalNumber", "bankCode"]
        nullable_fields = ["userType", "userFisNumber", "fiscalNumber", "bankCode"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Any, Dict, List
from typing_extensions import NotRequired, TypedDict


class AdyenSplitsOptionsTypedDict(TypedDict):
    authorization: NotRequired[Nullable[List[Dict[str, Any]]]]
    r"""Split payment values to pass to the Adyen API on payment authorization. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-payments-at-authorization/) for details on the format and contents of the list."""
    capture: NotRequired[Nullable[List[Dict[str, Any]]]]
    r"""Split payment values to pass to the Adyen API on payment capture. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-payments-at-capture/) for details on the format and contents of the list."""
    refund: NotRequired[Nullable[List[Dict[str, Any]]]]
    r"""Split payment values to pass to the Adyen API on payment refund. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-refunds/) for details on the format and contents of the list."""


class AdyenSplitsOptions(BaseModel):
    authorization: OptionalNullable[List[Dict[str, Any]]] = UNSET
    r"""Split payment values to pass to the Adyen API on payment authorization. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-payments-at-authorization/) for details on the format and contents of the list."""

    capture: OptionalNullable[List[Dict[str, Any]]] = UNSET
    r"""Split payment values to pass to the Adyen API on payment capture. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-payments-at-capture/) for details on the format and contents of the list."""

    refund: OptionalNullable[List[Dict[str, Any]]] = UNSET
    r"""Split payment values to pass to the Adyen API on payment refund. See [the Adyen docs](https://docs.adyen.com/platforms/online-payments/split-transactions/split-refunds/) for details on the format and contents of the list."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["authorization", "capture", "refund"]
        nullable_fields = ["authorization", "capture", "refund"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .airline import Airline, AirlineTypedDict
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing_extensions import NotRequired, TypedDict


class TransactionCaptureCreateTypedDict(TypedDict):
    r"""Request body for capturing an authorized transaction."""

    amount: NotRequired[Nullable[int]]
    r"""The amount to capture, in the smallest currency unit (e.g., cents). This must be less than or equal to the authorized amount, unless over-capture is available."""
    airline: NotRequired[Nullable[AirlineTypedDict]]
    r"""The airline data to submit to the payment service during the capture call."""


class TransactionCaptureCreate(BaseModel):
    r"""Request body for capturing an authorized transaction."""

    amount: OptionalNullable[int] = UNSET
    r"""The amount to capture, in the smallest currency unit (e.g., cents). This must be less than or equal to the authorized amount, unless over-capture is available."""

    airline: OptionalNullable[Airline] = UNSET
    r"""The airline data to submit to the payment service during the capture call."""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["amount", "airline"]
        nullable_fields = ["amount", "airline"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m



"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .braintreedynamicdatafieldsoptions import (
    BraintreeDynamicDataFieldsOptions,
    BraintreeDynamicDataFieldsOptionsTypedDict,
)
from gr4vy.types import BaseModel, Nullable, OptionalNullable, UNSET, UNSET_SENTINEL
from pydantic import model_serializer
from typing import Dict
from typing_extensions import NotRequired, TypedDict


class BraintreeOptionsTypedDict(TypedDict):
    discount_amount: NotRequired[Nullable[int]]
    r"""Passes a discount amount to be applied to the transaction when using Braintree."""
    custom_fields: NotRequired[Nullable[Dict[str, str]]]
    r"""Passes `customFields` to the Braintree API when creating a new payment. Custom fields allow you to customize your checkout experience by collecting specific information about your customers and their purchases."""
    dynamic_data_fields: NotRequired[
        Nullable[BraintreeDynamicDataFieldsOptionsTypedDict]
    ]
    r"""Additional dynamic fields to pass to the Braintree API"""


class BraintreeOptions(BaseModel):
    discount_amount: OptionalNullable[int] = UNSET
    r"""Passes a discount amount to be applied to the transaction when using Braintree."""

    custom_fields: OptionalNullable[Dict[str, str]] = UNSET
    r"""Passes `customFields` to the Braintree API when creating a new payment. Custom fields allow you to customize your checkout experience by collecting specific information about your customers and their purchases."""

    dynamic_data_fields: OptionalNullable[BraintreeDynamicDataFieldsOptions] = UNSET
    r"""Additional dynamic fields to pass to the Braintree API"""

    @model_serializer(mode="wrap")
    def serialize_model(self, handler):
        optional_fields = ["discount_amount", "custom_fields", "dynamic_data_fields"]
        nullable_fields = ["discount_amount", "custom_fields", "dynamic_data_fields"]
        null_default_fields = []

        serialized = handler(self)

        m = {}

        for n, f in type(self).model_fields.items():
            k = f.alias or n
            val = serialized.get(k)
            serialized.pop(k, None)

            optional_nullable = k in optional_fields and k in nullable_fields
            is_set = (
                self.__pydantic_fields_set__.intersection({n})
                or k in null_default_fields
            )  # pylint: disable=no-member

            if val is not None and val != UNSET_SENTINEL:
                m[k] = val
            elif val != UNSET_SENTINEL and (
                not k in optional_fields or (optional_nullable and is_set)
            ):
                m[k] = val

        return m
